@@ -1,6 +1,8 @@
 from os.path import join as pjoin, abspath, dirname, pardir
 
+import django
 
+SECRET_KEY = 'SECRET'
 PROJ_ROOT = abspath(pjoin(dirname(__file__), pardir))
 DATA_ROOT = pjoin(PROJ_ROOT, 'data')
 THUMBNAIL_PREFIX = 'test/cache/'
@@ -18,17 +20,31 @@ ADMINS = (
 DATABASES = {
     'default': {
         'ENGINE': 'django.db.backends.sqlite3',
-        'NAME': 'thumbnail_tests',
+        'NAME': ':memory:',
     }
 }
 MEDIA_ROOT = pjoin(PROJ_ROOT, 'media')
 MEDIA_URL = '/media/'
 ROOT_URLCONF = 'thumbnail_tests.urls'
-INSTALLED_APPS = (
-    'thumbnail',
-    'thumbnail_tests',
-)
+if django.VERSION < (1, 6):
+    INSTALLED_APPS = (
+        'thumbnail',
+        'thumbnail_tests',
+    )
+else:
+    INSTALLED_APPS = (
+        'sorl.thumbnail',
+        'tests.thumbnail_tests',
+    )
+
 TEMPLATE_CONTEXT_PROCESSORS = (
     "django.core.context_processors.request",
 )
-
+MIDDLEWARE_CLASSES = (
+    'django.contrib.sessions.middleware.SessionMiddleware',
+    'django.middleware.common.CommonMiddleware',
+    'django.middleware.csrf.CsrfViewMiddleware',
+    'django.contrib.auth.middleware.AuthenticationMiddleware',
+    'django.contrib.messages.middleware.MessageMiddleware',
+    'django.middleware.clickjacking.XFrameOptionsMiddleware',
+)
